@@ -1,9 +1,9 @@
 from ..imports import *
-from .manager_utils import FlanManager
+from .manager import FlanManager
 # ----------------------------------------------------------------------
 # Convenience accessors
 # ----------------------------------------------------------------------
-def get_flan_manager() -> FlanManager:
+def get_flan_manager():
     """Return singleton FlanManager instance."""
     return FlanManager()
 def get_flan_title(content):
